@@ -1,5 +1,5 @@
 package Playwright;
-$Playwright::VERSION = '1.250';
+$Playwright::VERSION = '1.251';
 use strict;
 use warnings;
 
@@ -110,7 +110,7 @@ sub new ( $class, %options ) {
             pid     => _start_server(
                 $port, $timeout, $options{debug}, $options{cleanup} // 1
             ),
-            parent  => $$,
+            parent  => $$ // 'bogus',    # Oh lawds, this can be undef sometimes
             timeout => $timeout,
         },
         $class
@@ -212,7 +212,9 @@ sub quit ($self) {
 
     # Prevent destructor from firing in child processes so we can do things like async()
     # This should also prevent the waitpid below from deadlocking due to two processes waiting on the same pid.
-    return unless $$ == $self->{parent} // 'bogus';
+    my $ppid = $$ // 'hokum'
+      ;    # If $$ is undef both here and in the parent, let's just keep going
+    return unless $ppid == $self->{parent};
 
     # Prevent destructor from firing in the event the caller instructs it to not fire
     return unless $self->{cleanup};
@@ -255,7 +257,9 @@ sub _start_server ( $port, $timeout, $debug, $cleanup ) {
     # Check if the port is already live, and short-circuit if this is the case.
     if ( Net::EmptyPort::wait_port( $port, 1 ) ) {
         print "Re-using playwright server on port $port...\n" if $debug;
-        return;
+
+        # Set the PID as something bogus, we don't really care as we won't kill it
+        return "REUSE";
     }
 
     $ENV{DEBUG} = 'pw:api' if $debug;
@@ -300,7 +304,7 @@ Playwright - Perl client for Playwright
 
 =head1 VERSION
 
-version 1.250
+version 1.251
 
 =head1 SYNOPSIS
 
